@@ -19,22 +19,18 @@ from sunpy.util import SunpyUserWarning
 try:
     import matplotlib
     import matplotlib.pyplot as plt
-except ImportError:
-    HAVE_MATPLOTLIB = False
-else:
+
     HAVE_MATPLOTLIB = True
     matplotlib.use('Agg')
+except ImportError:
+    HAVE_MATPLOTLIB = False
 
 # Don't actually import pytest_remotedata because that can do things to the
 # entrypoints code in pytest.
 remotedata_spec = importlib.util.find_spec("pytest_remotedata")
 HAVE_REMOTEDATA = remotedata_spec is not None
-
-
 # Do not collect the sample data file because this would download the sample data.
 collect_ignore = ["data/sample.py"]
-
-
 console_logger = logging.getLogger()
 console_logger.setLevel('INFO')
 
@@ -104,7 +100,7 @@ def sunpy_cache(mocker, tmp_path):
     def func(mocked):
         mocker.patch(mocked, cache)
         return cache
-    yield func
+    return func
 
 
 @pytest.fixture()
@@ -118,6 +114,17 @@ def undo_config_dir_patch():
     os.environ["SUNPY_CONFIGDIR"] = oridir
 
 
+@pytest.fixture(scope='session', autouse=True)
+def sunpy_test_run(request):
+    """
+    Add a environmental keyword to allow us to check and execute
+    specific code within a pytest run (e.g., update headers for the online tests).
+    """
+    os.environ["SUNPY_PYTEST_RUN"] = "True"
+    yield
+    del os.environ["SUNPY_PYTEST_RUN"]
+
+
 @pytest.fixture(scope='session', autouse=True)
 def hide_parfive_progress(request):
     """
