@@ -2,13 +2,14 @@
 import pytest
 
 import astropy.units as u
-from astropy.coordinates import ICRS, HeliocentricMeanEcliptic, get_body_barycentric
+from astropy.coordinates import ICRS, HeliocentricMeanEcliptic, SphericalRepresentation, get_body_barycentric
 from astropy.tests.helper import assert_quantity_allclose
 from astropy.time import Time
 
 from sunpy.coordinates import frames, get_earth
 from sunpy.coordinates.frameattributes import ObserverCoordinateAttribute, TimeFrameAttributeSunPy
 from sunpy.coordinates.frames import (
+    Heliocentric,
     HeliocentricInertial,
     HeliographicCarrington,
     HeliographicStonyhurst,
@@ -116,6 +117,17 @@ def test_observer_not_hgs_astropy(oca):
     assert converted
 
 
+def test_observer_not_default_representation(oca):
+    observer = HeliographicStonyhurst((1, 0, 0) * u.AU, representation_type='cartesian',
+                                      obstime='2001-01-01')
+    result, converted = oca.convert_input(observer)
+
+    assert isinstance(result, HeliographicStonyhurst)
+    assert issubclass(result.representation_type, SphericalRepresentation)
+    assert result.obstime == observer.obstime
+    assert converted
+
+
 def test_coord_get():
 
     # Test default (instance=None)
@@ -193,3 +205,12 @@ def test_obstime_hack():
     assert_quantity_allclose(obs.lon, earth.lon)
     assert_quantity_allclose(obs.lat, earth.lat)
     assert_quantity_allclose(obs.radius, earth.radius)
+
+
+@pytest.mark.parametrize('frame_class', [Heliocentric, HeliographicCarrington, Helioprojective])
+def test_observer_in_heeq(frame_class):
+    # An observer provided in HGS Cartesian (i.e., HEEQ) should be converted to HGS spherical
+    obs_heeq = HeliographicStonyhurst((3, 4, 12)*u.AU, representation_type='cartesian')
+    frame = frame_class(observer=obs_heeq)
+    assert issubclass(frame.observer.representation_type, SphericalRepresentation)
+    assert_quantity_allclose(frame.observer.radius, 13*u.AU)
