@@ -407,39 +407,39 @@ def test_walker_create_fitsheader_inverted(session):
 @pytest.mark.skip
 def test_walker_create_vso_instrument(vso_session):
     entries = walker.create(a.Instrument.rhessi, vso_session)
-    expected = [tables.DatabaseEntry(id=1, source=u'RHESSI', provider=u'LSSP',
-                                     physobs=u'intensity',
-                                     fileid=u'/hessidata/2011/09/19/hsi_20110919_233340_002.fits',
+    expected = [tables.DatabaseEntry(id=1, source='RHESSI', provider='LSSP',
+                                     physobs='intensity',
+                                     fileid='/hessidata/2011/09/19/hsi_20110919_233340_002.fits',
                                      observation_time_start=datetime(2011, 9, 19, 23, 33, 40),
                                      observation_time_end=datetime(2011, 9, 20, 1, 9, 20),
-                                     instrument=u'RHESSI',
+                                     instrument='RHESSI',
                                      size=-1.0,
                                      wavemin=0.4132806579880238,
                                      wavemax=7.293188082141598e-05),
-                tables.DatabaseEntry(id=2, source=u'RHESSI', provider=u'LSSP',
-                                     physobs=u'intensity',
-                                     fileid=u'/hessidata/2011/09/19/hsi_20110919_233340_002.fits',
+                tables.DatabaseEntry(id=2, source='RHESSI', provider='LSSP',
+                                     physobs='intensity',
+                                     fileid='/hessidata/2011/09/19/hsi_20110919_233340_002.fits',
                                      observation_time_start=datetime(2011, 9, 19, 23, 33, 40),
                                      observation_time_end=datetime(2011, 9, 20, 1, 9, 20),
-                                     instrument=u'RHESSI',
+                                     instrument='RHESSI',
                                      size=-1.0,
                                      wavemin=0.4132806579880238,
                                      wavemax=7.293188082141598e-05),
-                tables.DatabaseEntry(id=1, source=u'RHESSI', provider=u'LSSP',
-                                     physobs=u'intensity',
-                                     fileid=u'/hessidata/2011/09/20/hsi_20110920_010920_001.fits',
+                tables.DatabaseEntry(id=1, source='RHESSI', provider='LSSP',
+                                     physobs='intensity',
+                                     fileid='/hessidata/2011/09/20/hsi_20110920_010920_001.fits',
                                      observation_time_start=datetime(2011, 9, 20, 1, 9, 20),
                                      observation_time_end=datetime(2011, 9, 20, 2, 27, 40),
-                                     instrument=u'RHESSI',
+                                     instrument='RHESSI',
                                      size=-1.0,
                                      wavemin=0.41328066144400083,
                                      wavemax=7.293188143129426e-05),
-                tables.DatabaseEntry(id=2, source=u'RHESSI', provider=u'LSSP',
-                                     physobs=u'intensity',
-                                     fileid=u'/hessidata/2011/09/20/hsi_20110920_010920_001.fits',
+                tables.DatabaseEntry(id=2, source='RHESSI', provider='LSSP',
+                                     physobs='intensity',
+                                     fileid='/hessidata/2011/09/20/hsi_20110920_010920_001.fits',
                                      observation_time_start=datetime(2011, 9, 20, 1, 9, 20),
                                      observation_time_end=datetime(2011, 9, 20, 2, 27, 40),
-                                     instrument=u'RHESSI',
+                                     instrument='RHESSI',
                                      size=-1.0,
                                      wavemin=0.41328066144400083,
                                      wavemax=7.293188143129426e-05)]
@@ -463,21 +463,21 @@ def test_walker_create_time(vso_session):
         datetime(2011, 9, 17, 0, 0, 0), datetime(2011, 9, 20, 0, 0, 0))
     entries = walker.create(time, vso_session)
     assert len(entries) == 1
-    expected = [tables.DatabaseEntry(id=1, source=u'RHESSI', provider=u'LSSP',
-                                     physobs=u'intensity',
-                                     fileid=u'/hessidata/2011/09/19/hsi_20110919_233340_002.fits',
+    expected = [tables.DatabaseEntry(id=1, source='RHESSI', provider='LSSP',
+                                     physobs='intensity',
+                                     fileid='/hessidata/2011/09/19/hsi_20110919_233340_002.fits',
                                      observation_time_start=datetime(2011, 9, 19, 23, 33, 40),
                                      observation_time_end=datetime(2011, 9, 20, 1, 9, 20),
-                                     instrument=u'RHESSI',
+                                     instrument='RHESSI',
                                      size=-1.0,
                                      wavemin=0.4132806579880238,
                                      wavemax=7.293188082141598e-05),
-                tables.DatabaseEntry(id=2, source=u'RHESSI', provider=u'LSSP',
-                                     physobs=u'intensity',
-                                     fileid=u'/hessidata/2011/09/19/hsi_20110919_233340_002.fits',
+                tables.DatabaseEntry(id=2, source='RHESSI', provider='LSSP',
+                                     physobs='intensity',
+                                     fileid='/hessidata/2011/09/19/hsi_20110919_233340_002.fits',
                                      observation_time_start=datetime(2011, 9, 19, 23, 33, 40),
                                      observation_time_end=datetime(2011, 9, 20, 1, 9, 20),
-                                     instrument=u'RHESSI',
+                                     instrument='RHESSI',
                                      size=-1.0,
                                      wavemin=0.41328066144400083,
                                      wavemax=7.293188143129426e-05)]
