@@ -7,7 +7,7 @@ from collections import deque
 
 import pytest
 
-from sunpy.database.caching import BaseCache, LRUCache, LFUCache
+from sunpy.database.caching import BaseCache, LFUCache, LRUCache
 
 
 def test_custom_cache():
