@@ -8,7 +8,7 @@ from sunpy.io import ana
 from sunpy.tests.helpers import skip_ana
 
 img_size = (456, 345)
-img_src = np.arange(np.product(img_size))
+img_src = np.arange(np.prod(img_size))
 img_src.shape = img_size
 img_i8 = img_src*2**8/img_src.max()
 img_i8 = img_i8.astype(np.int8)
