@@ -384,6 +384,7 @@ _map_meta_keywords = {
     'Matrix element CDi_j describing the rotation required to align solar North with the top of the image.'
 }
 
+
 @u.quantity_input
 def make_heliographic_header(date, observer_coordinate, shape, *, frame, projection_code="CAR",
                              map_center_longitude: u.Quantity[u.deg] = 0.0*u.deg):
@@ -426,7 +427,33 @@ def make_heliographic_header(date, observer_coordinate, shape, *, frame, project
     >>> observer = get_earth(date)
     >>> header = make_heliographic_header(date, observer, [90, 180], frame='carrington')
     >>> header
-    MetaDict([('wcsaxes', 2), ('crpix1', 90.5), ('crpix2', 45.5), ('cdelt1', 2.0), ('cdelt2', 2.0), ('cunit1', 'deg'), ('cunit2', 'deg'), ('ctype1', 'CRLN-CAR'), ('ctype2', 'CRLT-CAR'), ('crval1', 0.0), ('crval2', 0.0), ('lonpole', 0.0), ('latpole', 90.0), ('mjdref', 0.0), ('date-obs', '2020-01-01T12:00:00.000'), ('rsun_ref', 695700000.0), ('dsun_obs', 147096975776.97), ('hgln_obs', 0.0), ('hglt_obs', -3.0011725838606), ('naxis', 2), ('naxis1', 180), ('naxis2', 90), ('pc1_1', 1.0), ('pc1_2', -0.0), ('pc2_1', 0.0), ('pc2_2', 1.0), ('rsun_obs', 975.5398432033492)])
+    MetaDict([('wcsaxes': '2')
+    ('crpix1': '90.5')
+    ('crpix2': '45.5')
+    ('cdelt1': '2.0')
+    ('cdelt2': '2.0')
+    ('cunit1': 'deg')
+    ('cunit2': 'deg')
+    ('ctype1': 'CRLN-CAR')
+    ('ctype2': 'CRLT-CAR')
+    ('crval1': '0.0')
+    ('crval2': '0.0')
+    ('lonpole': '0.0')
+    ('latpole': '90.0')
+    ('mjdref': '0.0')
+    ('date-obs': '2020-01-01T12:00:00.000')
+    ('rsun_ref': '695700000.0')
+    ('dsun_obs': '147096975776.97')
+    ('hgln_obs': '0.0')
+    ('hglt_obs': '-3.0011725838606')
+    ('naxis': '2')
+    ('naxis1': '180')
+    ('naxis2': '90')
+    ('pc1_1': '1.0')
+    ('pc1_2': '-0.0')
+    ('pc2_1': '0.0')
+    ('pc2_2': '1.0')
+    ('rsun_obs': '975.53984320334...
 
     .. minigallery:: sunpy.map.make_heliographic_header
     """
