@@ -1,5 +1,6 @@
 import json
 import pathlib
+from concurrent.futures import ThreadPoolExecutor
 
 import requests
 
@@ -26,8 +27,8 @@ def get_observatory_groups():
     --------
     >>> from sunpy.net.cdaweb import get_observatory_groups
     >>>
-    >>> groups = get_observatory_groups() #doctest: +REMOTE_DATA
-    >>> groups['Group'] #doctest: +REMOTE_DATA
+    >>> groups = get_observatory_groups() # doctest: +REMOTE_DATA
+    >>> groups['Group'] # doctest: +REMOTE_DATA
         <Column name='Group' dtype='str55' length=...>
                         ACE
                         AIM
@@ -35,7 +36,7 @@ def get_observatory_groups():
         ...
                     Voyager
                        Wind
-    >>> groups.loc['STEREO'] #doctest: +REMOTE_DATA
+    >>> groups.loc['STEREO'] # doctest: +REMOTE_DATA
     <Row index=...>
     Group                                  Observatories
     str55                                      str...
@@ -78,17 +79,18 @@ def get_datasets(observatory):
     --------
     >>> from sunpy.net.cdaweb import get_datasets
     >>>
-    >>> datasets = get_datasets('STEREOB') #doctest: +REMOTE_DATA
-    >>> datasets['Id'] #doctest: +REMOTE_DATA
-    <Column name='Id' dtype='str17' length=4>
+    >>> datasets = get_datasets('STEREOB') # doctest: +REMOTE_DATA
+    >>> datasets['Id'] # doctest: +REMOTE_DATA
+    <Column name='Id' dtype='str17' length=5>
         STB_LB_IMPACT
     STB_L1_IMPACT_HKP
            STB_L1_HET
+      STB_L2_SWEA_PAD
      STB_L1_SWEA_SPEC
-    >>> datasets.loc['STB_L1_SWEA_SPEC']['Label'] #doctest: +REMOTE_DATA
+    >>> datasets.loc['STB_L1_SWEA_SPEC']['Label'] # doctest: +REMOTE_DATA
     'STEREO Behind IMPACT/SWEA Spectra - J. Luhmann (UCB/SSL)'
-    >>> datasets.loc['STB_L1_SWEA_SPEC'][['Start', 'End']] #doctest: +REMOTE_DATA
-    <Row index=3>
+    >>> datasets.loc['STB_L1_SWEA_SPEC'][['Start', 'End']] # doctest: +REMOTE_DATA
+    <Row index=4>
              Start                     End
              str24                    str24
     ------------------------ ------------------------
@@ -125,15 +127,24 @@ def _update_cdaweb_dataset_data():
     ])
     # Mapping from dataset ID to description
     all_datasets = {}
-    for group in all_obs['Group']:
-        print(f'🛰 Getting datasets for {group}')
-        group_url = url + f'?observatoryGroup={group}'
-        response = requests.get(group_url, headers=_CDAS_HEADERS)
+    # Number of parallel threads we spawn
+    N = 3
 
-        datasets = response.json()['DatasetDescription']
+    def _fetch_cdaweb_dataset(group, url=url):
+        print(f'🛰 Getting datasets for {group}')
+        u = url + f'?observatoryGroup={group}'
+        res = requests.get(u, headers=_CDAS_HEADERS)
+        datasets = res.json()['DatasetDescription']
         dataset_ids = {ds['Id']: ds['Label'] for ds in datasets}
         all_datasets.update(dataset_ids)
 
+    with ThreadPoolExecutor(max_workers=N) as executor:
+        # Submit each URL to the thread pool
+        futures = [executor.submit(_fetch_cdaweb_dataset, group) for group in all_obs['Group']]
+        # Wait for all tasks to complete
+        for future in futures:
+            future.result()
+
     attr_file = pathlib.Path(__file__).parent / 'data' / 'attrs.json'
     with open(attr_file, 'w') as attrs_file:
         json.dump(dict(sorted(all_datasets.items())), attrs_file, indent=2)
