@@ -107,7 +107,7 @@ def test_fetch_working(suvi_client):
 
 
 @pytest.mark.remote_data
-@pytest.mark.parametrize("start, end, wave, expected_num_files",
+@pytest.mark.parametrize(('start', 'end', 'wave', 'expected_num_files'),
                          [('2019/05/25 00:50', '2019/05/25 00:52', 94, 1),
                           ('2019/05/25 00:50', '2019/05/25 00:52', 131, 1),
                           ('2019/05/25 00:50', '2019/05/25 00:52', 171, 1),
@@ -124,7 +124,7 @@ def test_get_url_for_time_range_level2(suvi_client, start, end, wave, expected_n
 
 
 @pytest.mark.remote_data
-@pytest.mark.parametrize("start, end, expected_num_files",
+@pytest.mark.parametrize(('start', 'end', 'expected_num_files'),
                          [('2019/05/25 00:50', '2019/05/25 00:52', 6)]
                          )
 def test_get_url_for_time_range_level2_allwave(suvi_client, start, end, expected_num_files):
@@ -137,7 +137,7 @@ def test_get_url_for_time_range_level2_allwave(suvi_client, start, end, expected
 
 
 @pytest.mark.remote_data
-@pytest.mark.parametrize("start, end ,wave, expected_num_files",
+@pytest.mark.parametrize(('start', 'end', 'wave', 'expected_num_files'),
                          [('2019/05/25 00:50', '2019/05/25 00:54', 94, 6),
                           ('2019/05/25 00:50', '2019/05/25 00:54', 131, 3),
                           ('2019/05/25 00:50', '2019/05/25 00:54', 171, 2),
@@ -156,7 +156,7 @@ def test_get_url_for_time_range_level1b(suvi_client, start, end, wave, expected_
 
 
 @pytest.mark.remote_data
-@pytest.mark.parametrize("start, end ,wave, expected_num_files",
+@pytest.mark.parametrize(('start', 'end', 'wave', 'expected_num_files'),
                          [('2019/05/25 00:50', '2019/05/25 00:54', 94, 6),
                           ('2019/05/25 00:50', '2019/05/25 00:54', 131, 3),
                           ('2019/05/25 00:50', '2019/05/25 00:54', 171, 2),
@@ -172,7 +172,7 @@ def test_fido_onewave_level1b(start, end, wave, expected_num_files):
 
 
 @pytest.mark.remote_data
-@pytest.mark.parametrize("start, end, wave1, wave2, expected_num_files",
+@pytest.mark.parametrize(('start', 'end', 'wave1', 'wave2', 'expected_num_files'),
                          [('2019/05/25 00:50', '2019/05/25 00:54', 1, 100, 6),
                           ('2019/05/25 00:50', '2019/05/25 00:54', 1, 150, 9),
                           ('2019/05/25 00:50', '2019/05/25 00:54', 1, 180, 11),
@@ -190,7 +190,7 @@ def test_fido_waverange_level1b(start, end, wave1, wave2, expected_num_files):
 
 
 @pytest.mark.remote_data
-@pytest.mark.parametrize("start, end, expected_num_files",
+@pytest.mark.parametrize(('start', 'end', 'expected_num_files'),
                          [('2019/05/25 00:50', '2019/05/25 00:52', 6)]
                          )
 def test_query(suvi_client, start, end, expected_num_files):
