@@ -95,7 +95,7 @@ def vso_attribute_parse(phrase):
         avg_wave_len = phrase['obs_meanwavel'] * units.Unit(phrase['obs_wavelunit'])
         query.append(a.Wavelength(avg_wave_len, avg_wave_len))
     except (KeyError, TypeError):
-        raise TypeError("'{dtype!s}' is an improper data type".format(dtype=type(phrase)))
+        raise TypeError(f"'{type(phrase)!s}' is an improper data type")
     return query
 
 
