@@ -248,7 +248,7 @@ class JSOCClient(BaseClient):
 
         *Example 2*
 
-        Request keyword data of ``hmi.v_45s`` and show specific columns only::
+        Request keyword data of "hmi.v_45s" and show specific columns only::
 
             >>> import astropy.units as u
             >>> from sunpy.net import jsoc
@@ -483,7 +483,7 @@ class JSOCClient(BaseClient):
         # Private communication from JSOC say we should not use more than one connection.
         max_splits = kwargs.get('max_splits', 1)
         if max_splits != 1:
-            log.info(f"Setting max_splits to it's maximum allowed value of 1 for requests made by the JSOCClient.")
+            log.info("Setting max_splits to it's maximum allowed value of 1 for requests made by the JSOCClient.")
             max_splits = 1
 
         # Convert Responses to a list if not already
@@ -533,12 +533,8 @@ class JSOCClient(BaseClient):
             dl_set = False
             # Private communication from JSOC say we should not use more than one connection.
             if max_conn != self.default_max_conn:
-                log.info(f"Setting max parallel downloads to 1 for the JSOC client.")
-            if parfive_version >= Version("2.0.0"):
-                downloader = Downloader(max_conn=max_conn, progress=progress, overwrite=overwrite, max_splits=max_splits)
-            else:
-                downloader = Downloader(max_conn=max_conn, progress=progress, overwrite=overwrite)
-
+                log.info("Setting max parallel downloads to 1 for the JSOC client.")
+            downloader = Downloader(max_conn=max_conn, progress=progress, overwrite=overwrite, max_splits=max_splits)
         urls = []
         for request in requests:
             if request.status == 0:
@@ -665,7 +661,7 @@ class JSOCClient(BaseClient):
                     wavelength = [int(np.ceil(wave.to(u.AA).value)) for wave in wavelength]
                     wavelength = str(wavelength)
                 else:
-                    wavelength = '{}'.format(int(np.ceil(wavelength.to(u.AA).value)))
+                    wavelength = f'{int(np.ceil(wavelength.to(u.AA).value))}'
             else:
                 # This is executed when wavelength has been passed both through PrimeKey()
                 # and Wavelength().
@@ -841,7 +837,7 @@ class JSOCClient(BaseClient):
         from sunpy.net import attrs as a
 
         here = os.path.dirname(os.path.realpath(__file__))
-        with open(os.path.join(here, 'data', 'attrs.json'), 'r') as attrs_file:
+        with open(os.path.join(here, 'data', 'attrs.json')) as attrs_file:
             keyword_info = json.load(attrs_file)
         # Create attrs out of them.
         series_dict = {a.jsoc.Series: keyword_info["series_store"]}
