@@ -4,9 +4,6 @@ This module provides Proba-2 `~sunpy.timeseries.TimeSeries` source.
 import sys
 from collections import OrderedDict
 
-import matplotlib.dates as mdates
-import matplotlib.pyplot as plt
-import numpy as np
 import pandas
 
 import astropy.units as u
@@ -16,6 +13,7 @@ import sunpy.io
 from sunpy import config
 from sunpy.time import parse_time
 from sunpy.timeseries.timeseriesbase import GenericTimeSeries
+from sunpy.util.decorators import deprecate_positional_args_since
 from sunpy.util.metadata import MetaDict
 from sunpy.visualization import peek_show
 
@@ -54,10 +52,12 @@ class LYRATimeSeries(GenericTimeSeries):
     * `LYRA Data Homepage <http://proba2.sidc.be/data/LYRA>`_
     * `LYRA Instrument Homepage <http://proba2.sidc.be/about/LYRA>`_
     """
-    # Class attribute used to specify the source class of the TimeSeries.
+    # Class attributes used to specify the source class of the TimeSeries
+    # and a URL to the mission website.
     _source = 'lyra'
+    _url = "https://proba2.sidc.be/about/LYRA"
 
-    def plot(self, axes=None, names=3, **kwargs):
+    def plot(self, axes=None, columns=None, names=3, **kwargs):
         """
         Plots the LYRA data.
 
@@ -65,6 +65,8 @@ class LYRATimeSeries(GenericTimeSeries):
         ----------
         axes : array of `matplotlib.axes.Axes`, optional
             The axes on which to plot the TimeSeries.
+        columns : list[str], optional
+            If provided, only plot the specified columns.
         names : `int`, optional
             The number of columns to plot. Defaults to 3.
         **kwargs : `dict`
@@ -75,37 +77,26 @@ class LYRATimeSeries(GenericTimeSeries):
         array of `~matplotlib.axes.Axes`
             The plot axes.
         """
-        self._validate_data_for_plotting()
-        lyranames = (('Lyman alpha', 'Herzberg cont.', 'Al filter', 'Zr filter'),
-                     ('120-123nm', '190-222nm', '17-80nm + <5nm', '6-20nm + <2nm'))
-        colors = ('tab:blue', 'tab:orange', 'tab:green', 'tab:red', 'tab:purple',
-                  'tab:brown', 'tab:pink', 'tab:gray', 'tab:olive', 'tab:cyan')
-        predefined_axes = False
-        if isinstance(axes, np.ndarray):
-            predefined_axes = True
-        elif axes is None:
-            axes = self.to_dataframe().plot(subplots=True, sharex=True, **kwargs)
-        for i, name in enumerate(self.to_dataframe().columns):
-            if predefined_axes:
-                axes[i].plot(self._data[self._data.columns[i]],
-                             color=colors[i % len(colors)],
-                             label=self._data.columns[i])
-                axes[i].legend(loc="upper right")
-                plt.xticks(rotation=30)
+        axes, columns = self._setup_axes_columns(axes, columns, subplots=True)
+        lyranames = ({'CHANNEL1': 'Lyman alpha', 'CHANNEL2': 'Herzberg cont.',
+                      'CHANNEL3': 'Al filter', 'CHANNEL4': 'Zr filter'},
+                     {'CHANNEL1': '120-123nm', 'CHANNEL2': '190-222nm',
+                      'CHANNEL3': '17-80nm + <5nm', 'CHANNEL4': '6-20nm + <2nm'})
+        for i, name in enumerate(columns):
+            axes[i].plot(self._data[columns[i]],
+                         label=columns[i])
+            axes[i].legend(loc="upper right")
             if names < 3:
-                name = lyranames[names][i]
+                name = lyranames[names][columns[i]]
             else:
-                name = lyranames[0][i] + ' \n (' + lyranames[1][i] + ')'
-            axes[i].locator_params(axis='y', nbins=6)
+                name = lyranames[0][columns[i]] + ' \n (' + lyranames[1][columns[i]] + ')'
             axes[i].set_ylabel(f"{name} \n (W/m**2)", fontsize=9.5)
-        locator = mdates.AutoDateLocator()
-        formatter = mdates.ConciseDateFormatter(locator)
-        axes[-1].xaxis.set_major_locator(locator)
-        axes[-1].xaxis.set_major_formatter(formatter)
+        self._setup_x_axis(axes)
         return axes
 
     @peek_show
-    def peek(self, title=None, names=3, **kwargs):
+    @deprecate_positional_args_since("4.1")
+    def peek(self, *, title=None, columns=None, names=3, **kwargs):
         """
         Displays the LYRA data by calling `~sunpy.timeseries.sources.lyra.LYRATimeSeries.plot`.
 
@@ -120,21 +111,19 @@ class LYRATimeSeries(GenericTimeSeries):
         ----------
         title : `str`, optional
             The title of the plot.
+        columns : list[str], optional
+            If provided, only plot the specified columns.
         names : `int`, optional
             The number of columns to plot. Defaults to 3.
         **kwargs : `dict`
             Additional plot keyword arguments that are handed to
             :meth:`pandas.DataFrame.plot`.
         """
-        axes = self.plot(names=names, **kwargs)
+        axes = self.plot(columns=columns, names=names, **kwargs)
         if title is None:
             title = "LYRA ({0:{1}})".format(self.to_dataframe().index[0], TIME_FORMAT)
-        axes[0].set_title(title)
-        fig = axes[-1].get_figure()
-        fig.subplots_adjust(left=0.17, top=0.94, right=0.94, bottom=0.15)
-        fig = axes[0].get_figure()
-        fig.subplots_adjust(left=0.17, top=0.94, right=0.94, bottom=0.15)
-        return fig
+            axes[0].set_title(title)
+        return axes[0].get_figure()
 
     @classmethod
     def _parse_file(cls, filepath):
