@@ -86,9 +86,9 @@ class BasicRegistrationFactory:
             else:
                 candidate_widget_types = [self.default_widget_type]
         elif n_matches > 1:
-            raise MultipleMatchError("Too many candidate types identified ({})."
+            raise MultipleMatchError(f"Too many candidate types identified ({n_matches})."
                                      "Specify enough keywords to guarantee unique type "
-                                     "identification.".format(n_matches))
+                                     "identification.")
 
         # Only one is found
         WidgetType = candidate_widget_types[0]
