@@ -51,17 +51,19 @@ def test_missing_dependencies_by_extra():
                                                    'database',
                                                    'dev',
                                                    'docs',
+                                                   'docs-gallery',
                                                    'image',
                                                    'jpeg2000',
                                                    'map',
                                                    'net',
+                                                   'spice',
                                                    'tests',
                                                    'timeseries',
                                                    'visualization'])
     missing = missing_dependencies_by_extra(exclude_extras=["all"])
     assert sorted(list(missing.keys())) == sorted(['asdf', 'required', 'dask', 'database', 'dev', 'docs',
-                                                   'image', 'jpeg2000', 'map', 'net', 'tests', 'timeseries',
-                                                   'visualization'])
+                                                   'docs-gallery', 'image', 'jpeg2000', 'map', 'net',
+                                                   'spice', 'tests', 'timeseries', 'visualization'])
 
 
 def test_resolve_requirement_versions():
